//
//	BoresightCcf.cc: - implementation of BoresightCcf class
//
//	AUTHOR:
//		U. Lammers, Tue May 20 17:49:54 MEST 2003
//
//	$Header: /sasbuild/sas_git_repo/cvs_copy/sasdev/sas/packages/ccftools/bscalgen/src/BoresightCcf.cc,v 1.1 2003/05/23 16:26:14 ulammers Exp $
//
#include <cstring>

#include "BoresightCcf.h"

void BoresightCcf::createAndFinalize(Xmm::Instrument instrument,
									 const EulerAngles &bsAngles)
{
	DataSet *set = dataSetServer->open(_name, DataSet::Create);
	*set->addAttribute("TELESCOP") = "XMM";
	*set->addAttribute("SCOPE") = "XMM";
	*set->addAttribute("TYPEID") = "BORESIGHT";
	*set->addAttribute("ISSUE") = 1;
	*set->addAttribute("VALDATE") = Xmm::missionStartTime.toString();
	*set->addAttribute("CATEGORY") = "XMMCCF";
	*set->addAttribute("EXTSEQID") = "BORESIGHT";
	*set->addAttribute("EXTSEQU") = "ANY";
	*set->addAttribute("SUBDATE") = STime::currentTime().toString();

	unsigned N = instrument==Xmm::EMOS1 ? 1 : 2;	// need always EMOS1
	Table *table = set->addTable("BORESIGHT", N);
	std::vector<unsigned long> size(1); size[0] = 5;

	char *_id = table->addColumn("INSTRUMENT_ID", Dal::DString, "", "", size)->
			data()->stringData();
	real64 *phi = table->addColumn("EULER_PHI", Dal::Real64, "rad")
				->data()->real64Data(),
		    *theta = table->addColumn("EULER_THETA", Dal::Real64, "rad")
				->data()->real64Data(),
			*psi = table->addColumn("EULER_PSI", Dal::Real64, "rad")
				->data()->real64Data();

	std::strncpy(_id, Xmm::toString(instrument).c_str(), 5);
	*phi = bsAngles.phi();
	*theta = bsAngles.theta();
	*psi = bsAngles.psi();
	if (N>1) {
		//	d/f EMOS1 entry
		std::strncpy(_id+5, Xmm::toString(Xmm::EMOS1).c_str(), 5);
		phi[1] = M_PI;
		theta[1] = 0.;
		psi[1] = 0.;
	}

	dataSetServer->close(set);
} // BoresightCcf::createAndFinalize()
